import pathlib
from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name="crinstaniev",
    version="1.0.1",
    description="The description of your package",
    long_description=README,
    long_description_content_type="text/markdown",
    # url="https://github.com/yourgithubname/yourpackagename",
    author="Your Name",
    author_email="example@abc.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
    ],
    # dependencies for installing the package
    install_requires=["numpy", "pandas"]
)